maps

package
v0.0.0-...-a89011a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 30, 2024 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Map2Struct

func Map2Struct(input interface{}, output interface{}) error

Map2Struct Decode takes an input structure and uses reflection to translate it to the output structure. output must be a pointer to a map or struct.

Types

This section is empty.

Jump to